##  Fact Sheet Subtypes
Subtypes are categories of fact sheet types used to group similar concepts. Subtypes share properties with other subtypes but have unique properties, for example, attributes and relations.
Not all fact sheets types have predefined subtypes.
If a fact sheet has predefined subtypes, when creating a new fact sheet it is a best practice always to assign a subtype to it even if technically n/a is also an option.
This overview shows the predefined subtypes in SAP LeanIX:
![Fact Sheet Subtypes](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fd95e7a441014ba2cd7fe405b0269_LowRes.png)
**Remember**
Note that there are optional fact sheet subtypes of the fact sheet type application that are not shown above. These subtypes allow you to specifically model deployments of applications or microservices that are considered applications. For these, the following restrictions and terms need to be to considered:
  * Microservice can only be added as an optional feature.
  * Business application can only and should be used if microservice fact sheets are used as well and will help to distinguish applications from microservices.


**Note**
Refer to [Add Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__add_fact_sheet_subtypes_to_several_fact_sheet_types) documentation page for a step-by-step guide to create the fact sheet subtype.
